@@ -34,12 +34,13 @@ FIELDS_TO_EXPORT = [
 ]
 
 
-def token_transfers_item_exporter(token_transfer_output):
+def token_transfers_item_exporter(token_transfer_output, converters=()):
     return CompositeItemExporter(
         filename_mapping={
             'token_transfer': token_transfer_output
         },
         field_mapping={
             'token_transfer': FIELDS_TO_EXPORT
-        }
+        },
+        converters=converters
     )
